# Introduction

This app is the generated outcome of the Triple CLI Tool for React Native.

# Contents

- [Introduction](#introduction)
- [Tech Stack](#tech-stack)
- [Requirements](#requirements)
- [Getting Started](#getting-started)
- [Deployment with Fastlane](#deployment-with-fastlane)
- [License](#license)

# Tech Stack

Triple apps include the following technical desicions out of the box:

- React Native
- React Navigation 6
- Typescript
- Eslint-config-triple
- React-native-svg (for SVG support)
- Axios for API Communication
- Clean Code Architecture

# Requirements

- Node support for v16.7.0 - v17.4.0
- Java SE Development Kit (JDK) v11 or newer
- Android Studio (For Android development only)
- Xcode with Cocoapods (For IOS development only)

# Getting Started

# Deployment with FastLane

Fastlane is the easiest way to automate beta deployments and releases for your iOS and Android apps. 🚀 It handles all tedious tasks, like generating screenshots, dealing with code signing, and releasing your application.

For more information see: https://docs.fastlane.tools/

## Deploy Quality Assurance and TestFlight

Triple has its own in house Quality Assurance App Center for testing iOS and Android apps and iOS also has TestFlight.

Create a Pipeline in [Azure Devops](https://dev.azure.com/)

### Android

1. Generate your own keystore file see https://reactnative.dev/docs/signed-apk-android

2. In android/app/build.gradle add a release config to singingConfigs and then change signingConfigs.debug --> signingConfigs.release

```gradle
release {
            // Caution! In production, you need to generate your own keystore file.
            // see https://reactnative.dev/docs/signed-apk-android.
            signingConfig signingConfigs.release
            minifyEnabled enableProguardInReleaseBuilds
            proguardFiles getDefaultProguardFile("proguard-android.txt"), "proguard-rules.pro"
        }
```

### iOS

1. Create an identifier , certificate and provisioning profile at [developer.apple.com](https://developer.apple.com/account/resources/identifiers)
2. Store the certificate with password in [dk](https://dk.triple-it.nl/ios)
3. Upload the certificate in the secure file store library of your repository on Azure DevOps.
4. Download the Provisioning Profile to the profiles directory in the iOS folder.

5. Add property profile_name to update_code_signing_settings in ios/fastlane/fastfile:

```ruby
    update_code_signing_settings(
      use_automatic_signing: false,
      path: project,
      team_id: ENV["TEAM_ID"],
      targets: scheme,
      build_configurations: configuration,
      bundle_identifier: ENV["IOS_BUNDLE_ID"],
-->  profile_name: "ProfileName"
    )
```

5. Generate a Api Authentication Key to surpass 2fa authentication.
6. Download the Api Authentication Key and upload the key in the secure file store library of your repository on Azure DevOps.
7. Add all variables and variable groups to Azure Devops: ios-configuration-qa , ios-configuration-testflight , quality-assurance, android-configuration, deployment-configuration.

# License

Triple React Native CLI is MIT licensed.
