import { FontSizes } from "models/font";
import { Theme } from "models/theme";

/**
 * Replace Triple Brand Colors with client brand colors and adjust theme where necessary
 */
const TRIPLE_BRAND_COLORS = {
  pink: "#FF4F68",
  yellow: "#FFD833",
  darkBlue: "#0E0940",
  green: "#2aF9C9",
  purple: "#5631E8",
  grey: "#F3F4F5",
};

const COLORS = {
  black: "#000000",
  white: "#ffffff",
  gray100: "#F3F4F5",
  gray200: "#EBECED",
  gray300: "#DDDDDE",
  gray400: "#B9BABB",
  gray500: "#9A9B9C",
  gray600: "#717273",
  gray700: "#5D5E5F",
  gray800: "#3F3F40",
  gray900: "#1E1F1F",
};

const FONT_SIZES: FontSizes = {
  x3s: 8,
  x2s: 10,
  xs: 12,
  s: 14,
  m: 16,
  l: 18,
  xl: 20,
  x2l: 22,
  x3l: 24,
  x4l: 30,
};

export const LINE_HEIGHTS = {
  xs: 16,
  s: 20,
  m: 24,
  l: 28,
  xl: 32,
  x2l: 40,
};

export const BORDER_RADIUSES = {
  xs: 1,
  s: 2,
  m: 3,
  l: 4,
  xl: 6,
  x2l: 8,
  x3l: 10,
  x4l: 16,
  x8l: 32,
  full: 100,
};

// The default unit to scale margins and paddings and keep spacing consistent.
// SpacingScale will be multiplied by this value.
export const THEME_SPACING_UNIT = 4;

/**
 * Defines theme on a global level.
 */
export const THEME: Theme = {
  palette: {
    primary: {
      main: TRIPLE_BRAND_COLORS.darkBlue,
      light: "#9093B6",
      dark: "#312b56"
    },
    secondary: {
      main: TRIPLE_BRAND_COLORS.pink,
      light: "#FF8894",
      dark: "#FF0025"
    },
    common: {
      black: COLORS.black,
      white: COLORS.white,
      gray100: COLORS.gray100,
      gray200: COLORS.gray200,
      gray300: COLORS.gray300,
      gray400: COLORS.gray400,
      gray500: COLORS.gray500,
      gray600: COLORS.gray600,
      gray700: COLORS.gray700,
      gray800: COLORS.gray800,
      gray900: COLORS.gray900,
      disabled: COLORS.gray300,
      disabledText: COLORS.gray500,
      text: COLORS.white
    },
    error: {
      main: "#FF0025",
      light: "#FF4F68",
      dark: "#CF000C"
    },
    warning: {
      main: "#FFD833",
      light: "#FAE631",
      dark: "#F88014"
    },
    info: {
      main: "#2AC2F9",
      light: "#ADE5FC",
      dark: "#0075C1"
    },
    success: {
      main: "#2AF9C9",
      light: "#9EFCDE",
      dark: "#00AB66"
    },
    background: TRIPLE_BRAND_COLORS.darkBlue
  },
  typography: {
    primary: {
      fontFamily: "",
      fontSize: FONT_SIZES.m,
      fontWeights: {
        light: "300",
        regular: "400",
        medium: "500",
        bold: "600"
      }
    },
    secondary: {
      fontFamily: "",
      fontSize: FONT_SIZES.m,
      fontWeights: {
        light: "300",
        regular: "400",
        medium: "500",
        bold: "600"
      }
    },
    fontSizes: FONT_SIZES
  },
  components: {
    button: {
      borderRadius: BORDER_RADIUSES.xl
    }
  },
  shadow: {
    elevation: 4,
    shadowColor: "#000",
    shadowOffset: {
      height: 2,
      width: 0,
    },
    shadowOpacity: 0.23,
    shadowRadius: 2.62,
  },
  spacing: (value) => {
    return value * THEME_SPACING_UNIT;
  },
};

export const THEME_DARK = {
  ...THEME,
};
