import { FontFamily, FontSizes, FontWeights } from "models/font";

export type SpacingScale =
| 0
| 0.25
| 0.5
| 1
| 1.5
| 2
| 2.5
| 3
| 3.5
| 4
| 5
| 6
| 7
| 8
| 9
| 10
| 11
| 12
| 14
| 16
| 20
| 24
| 28
| 32
| 36
| 40
| 44
| 48
| 52
| 56
| 60
| 64
| 72
| 80
| 96
| 128
| 200
| 256;

type Shadow = {
  shadowColor: string;
  shadowOffset: {
    width: number;
    height: number;
  };
  shadowOpacity: number;
  shadowRadius: number;
  elevation: number;
};

type Color = {
  main: string;
  light: string;
  dark: string;
};

type Common = {
  black: string;
  white: string;
  gray100: string;
  gray200: string;
  gray300: string;
  gray400: string;
  gray500: string;
  gray600: string;
  gray700: string;
  gray800: string;
  gray900: string;
  disabled: string;
  disabledText: string;
  text: string;
};

type Palette = {
  common: Common;
  primary: Color;
  secondary: Color;
  error: Color;
  warning: Color;
  info: Color;
  success: Color;
  background: string;
};

type Typography = {
  fontFamily: FontFamily;
  fontSize: number;
  fontWeights: FontWeights;
};

type StyledComponent = {
  borderRadius?: number;
  backgroundColor?: string;
  fontSize?: FontSizes;
  lineHeight?: number;
  color?: string;
};

export type Theme = {
  palette: Palette;
  shadow: Shadow;
  spacing: (value: SpacingScale) => number;
  typography: {
    primary: Typography;
    secondary: Typography;
    fontSizes: FontSizes;
  };
  components: {
    button: StyledComponent;
  };
};
