import { createBottomTabNavigator } from "@react-navigation/bottom-tabs";
import { NavigationContainer } from "@react-navigation/native";
import { createNativeStackNavigator } from "@react-navigation/native-stack";
import React, { useCallback } from "react";
import { Pressable } from "react-native";

import MoreIcon from "svg/more.svg";
import PostsIcon from "svg/posts.svg";
import SettingsIcon from "svg/settings.svg";
import useTheme from "hooks/use-theme";
/** :{i18n} import useTranslation from "hooks/use-translation"; */
import {
  RootStackParamList,
  RootTabParamList,
} from "models/root-stack-param-list";
import TabOne from "screens/demo/tab-one";
import TabTwo from "screens/demo/tab-two";
import Features from "screens/features";
import Welcome from "screens/welcome";
import Settings from "screens/settings";

const Stack = createNativeStackNavigator<RootStackParamList>();
const Tab = createBottomTabNavigator<RootTabParamList>();

const Tabs = () => {
  const { palette } = useTheme();
  const TabOneIcon = useCallback(
    () => <PostsIcon color={palette.common.white} />,
    []
  );
  const TabTwoIcon = useCallback(
    () => <MoreIcon color={palette.common.white} />,
    []
  );

  return (
    <Tab.Navigator
      screenOptions={{
        headerShown: false,
        tabBarStyle: { backgroundColor: palette.primary.main },
      }}
    >
      <Tab.Screen
        name="TabOne"
        component={TabOne}
        options={{
          tabBarIcon: TabOneIcon,
        }}
      />
      <Tab.Screen
        name="TabTwo"
        component={TabTwo}
        options={{
          tabBarIcon: TabTwoIcon,
        }}
      />
    </Tab.Navigator>
  );
};

const Main = () => {
  /** :{i18n} const { t } = useTranslation(); */
  const { palette, isDark } = useTheme();

  return (
    <NavigationContainer>
      <Stack.Navigator
        initialRouteName="Welcome"
        screenOptions={{
          headerShown: true,
          headerTitleAlign: "center",
          headerStyle: {
            backgroundColor: isDark
              ? palette.primary.main
              : palette.primary.light,
          },
          headerTitleStyle: {
            color: palette.common.white,
          },
          headerTintColor: palette.common.white,
        }}
      >
        <Stack.Group>
          <Stack.Screen
            name="Welcome"
            component={Welcome}
            /** :{i18n} options={{ title: t("Navigation/Powered") }} */
            /** :{!i18n} options={{ title: "Welcome" }} */
          />
          <Stack.Screen
            name="Features"
            component={Features}
            options={({ navigation }) => ({
              headerRight: () => {
                return (
                  <Pressable onPress={() => navigation.navigate("Settings")}>
                    <SettingsIcon color={palette.common.white} />
                  </Pressable>
                );
              },
            })}
          />
          <Stack.Screen
            name="Tabs"
            component={Tabs}
            /** :{i18n} options={{ title: t("Navigation/Tabs") }} */
            /** :{!i18n} options={{ title: "Tabs" }} */
          />
        </Stack.Group>
        <Stack.Group screenOptions={{ presentation: "modal" }}>
          <Stack.Screen
            name="Settings"
            component={Settings}
            /** :{i18n} options={{ title: t("Navigation/Preferences") }} */
            /** :{!i18n} options={{ title: "Preferences" }} */
          />
        </Stack.Group>
      </Stack.Navigator>
    </NavigationContainer>
  );
};

export default Main;
