import React from "react";
import {
  ActivityIndicator,
  Pressable,
  PressableProps,
  StyleProp,
  Text,
  ViewStyle,
} from "react-native";

import useMemoizedStyles from "hooks/use-memoized-styles";

import styles from "./button.style";

type Props = {
  label: string;
  isLoading?: boolean;
} & PressableProps;

const Button = ({
  disabled,
  label,
  isLoading = false,
  ...restProps
}: Props) => {
  const $ = styles();
  const computedStyles = useMemoizedStyles(({ palette }) => ({
    buttonBackground: {
      backgroundColor: disabled ? palette.common.disabled : palette.background,
    },
    textColor: {
      color: disabled ? palette.common.disabledText : palette.common.text,
    },
  }));

  return (
    <Pressable
      {...restProps}
      disabled={disabled}
      style={[
        $.button,
        computedStyles.buttonBackground,
        restProps.style as StyleProp<ViewStyle>,
      ]}
    >
      <Text style={[$.text, computedStyles.textColor]}>{label}</Text>
      {isLoading && <ActivityIndicator style={$.activityIndicator} />}
    </Pressable>
  );
};

export default Button;
