import React, { createContext, PropsWithChildren, useState } from "react";
import { IntlProvider as Provider } from "react-intl";

import en_GB from "locales/en/translation.json";
import nl_NL from "locales/nl/translation.json";
import { LANGUAGES } from "constants/i18n";

const defaultLanguage = { en: en_GB };

interface LanguageContext {
  locale: string;
  selectLanguage: (loc: string) => void;
}

export const Language = createContext<undefined | LanguageContext>(undefined);

const IntlProvider: React.FC<PropsWithChildren> = ({ children }) => {
  const [locale, setLocale] = useState(Object.keys(defaultLanguage)[0]);
  const [labels, setLabels] = useState(defaultLanguage.en);

  const selectLanguage = (loc: string) => {
    switch (loc) {
      case LANGUAGES.en:
        setLabels(en_GB);
        break;
      case LANGUAGES.nl:
        setLabels(nl_NL);
        break;
      default:
        setLabels(en_GB);
    }
    setLocale(loc);
  };

  return (
    <Language.Provider value={{ locale, selectLanguage }}>
      <Provider locale={locale} messages={labels}>
        {children}
      </Provider>
    </Language.Provider>
  );
};

export default IntlProvider;
