import { useEffect, useRef } from "react";

/** Returns a ref with the current mounted state, helps preventing state updates in async functions */
const useIsMounted = () => {
  const isMounted = useRef(false);
  useEffect(() => {
    isMounted.current = true;
    return () => {
      isMounted.current = false;
    };
  }, []);
  return isMounted;
};

export default useIsMounted;
