import React, { DependencyList } from "react";
import { StyleSheet } from "react-native";

import useTheme from "hooks/use-theme";
import { Theme } from "models/theme";
import { UnArray } from "utils/generics";

type CallbackReturn = UnArray<Parameters<typeof StyleSheet.create>>;

// In order to prevent allocating memory for new stylesheet object creation
const useMemoizedStyles = (
  callback: (theme: Theme) => CallbackReturn,
  dependencies?: DependencyList
) => {
  const theme = useTheme();
  const dependencyList = dependencies ? [...dependencies, theme] : [theme];
  return React.useMemo(
    () => StyleSheet.create(callback(theme)),
    dependencyList
  );
};

export default useMemoizedStyles;