/** :{examples} import { PostRequestPost } from "models/api-post"; */
/** :{examples} import { PutRequestPost } from "models/api-put"; */
import * as PostRepository from "repositories/posts";

import { useQuery, UseQueryOptions } from "@tanstack/react-query";

import * as endpoints from "constants/endpoints";

type GetPosts = Awaited<ReturnType<typeof PostRepository.getPosts>>;

export const usePosts = (
  userId?: number,
  options?: Omit<UseQueryOptions<GetPosts>, "queryKey" | "queryFn">
) => {
  return useQuery(
    [endpoints.POSTS, userId],
    () => {
      return PostRepository.getPosts(userId);
    },
    options
  );
};

type GetPost = Awaited<ReturnType<typeof PostRepository.getPost>>;

export const usePost = (
  id: number,
  options?: Omit<UseQueryOptions<GetPost>, "queryKey" | "queryFn">
) => {
  return useQuery(
    [endpoints.POST, id],
    () => {
      return PostRepository.getPost(id);
    },
    options
  );
};

{/** :{examples} type CreatePost = Awaited<
  ReturnType<typeof PostRepository.createPost>
>;

export const useCreatePost = (
  post: PostRequestPost,
  options?: Omit<UseQueryOptions<CreatePost>, "queryKey" | "queryFn">
) => {
  return useQuery(
    [endpoints.POSTS, post],
    () => {
      return PostRepository.createPost(post);
    },
    options
  );
};

type UpdatePost = Awaited<
  ReturnType<typeof PostRepository.updatePost>
>;

export const useUpdatePost = (
  post: PutRequestPost,
  options?: Omit<UseQueryOptions<UpdatePost>, "queryKey" | "queryFn">
) => {
  return useQuery(
    [endpoints.POSTS, post],
    () => {
      return PostRepository.updatePost(post);
    },
    options
  );
};

type DeletePost = Awaited<
  ReturnType<typeof PostRepository.deletePost>
>;

export const useDeletePost = (
  id: number,
  options?: Omit<UseQueryOptions<DeletePost>, "queryKey" | "queryFn">
) => {
  return useQuery(
    [endpoints.POSTS, id],
    () => {
      return PostRepository.deletePost(id);
    },
    options
  );
}; */}
