import { useIntl } from "react-intl";

import { FormatMessage, FormatNumber, FormatOptions } from "models/i18n";

/** Wrapper hook for exposing translation functions of react-intl. */
export default function useTranslation(): {
  t: FormatMessage;
  n: FormatNumber;
} {
  const { formatMessage, formatNumber } = useIntl();
  return {
    /** Transforms a number to a readable format like: '13.37' -> '€13,37' */
    n: (value = 0, options?: FormatOptions) => formatNumber(value, options),
    /** Translates a translation key to a readable label */
    t: (id = "", options?: FormatOptions) => {
      if (!id) return "";

      return formatMessage({ id }, options);
    },
  };
}
