import { BasicType } from "models/basic-type";

const PATTERN_OPTIONAL_PARAM = /\?\}/; // {someParam?} where '?}' matches pattern
const PATTERN_PARAM = /\{|\}|\?/g; // Matches a '{' or '}' or '?' in a string
const PATTERN_PARAM_ALL = /{(.*?)}/g; // Matches all {someWord} strings in a string
// eslint-disable-next-line no-useless-escape
const PATTERN_EMPTY_QUERY_PARAM = /[^\?][\w]+=(&|$)/gi; // ?key=&otherKey=123&anotherKey= matches 'key=&' and '&anotherKey='

const replaceQueryParams = (
  path: string,
  queryParams: Record<string, BasicType>
): { unusedParams: Record<string, BasicType>; newPath: string } => {
  let newPath = path;
  // Create new object reference
  const unusedParams = { ...queryParams };
  // Spread the query params to remove reference to the current object
  const matchedParams = path.match(PATTERN_PARAM_ALL);
  // No parameters found in path that can be replaced
  if (!matchedParams) {
    return { newPath, unusedParams };
  }
  matchedParams.forEach((match) => {
    const isOptionalParam = PATTERN_OPTIONAL_PARAM.test(match);
    const strippedParam = match.replace(PATTERN_PARAM, "");
    const paramValue = queryParams[strippedParam];
    if (typeof paramValue === "undefined") {
      // Param is not optional so throw an error that we are creating an url where a (query) param is missing
      if (!isOptionalParam) {
        throw new Error(`Missing param "${strippedParam}" for "${path}"`);
      }
    }
    // This param is now used, so remove it from the unusedParams
    delete unusedParams[strippedParam];
    // Replace param with paramValue in path, convert to string (number and boolean values needs to be converted)
    newPath = newPath.replace(match, paramValue?.toString() || "");
  });
  // Remove all empty query params
  newPath = newPath.replace(PATTERN_EMPTY_QUERY_PARAM, "");

  return {
    newPath,
    unusedParams,
  };
};

export default replaceQueryParams;
